#
# spec file for package python-zope.testbrowser
#
# Copyright (c) 2018 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%{?!python_module:%define python_module() python-%{**} python3-%{**}}
Name:           python-zope.testbrowser
Version:        5.2.4
Release:        3.31
Summary:        Programmable browser for functional black-box tests
License:        ZPL-2.1
Group:          Development/Languages/Python
Url:            https://github.com/zopefoundation/zope.testbrowser
Source:         https://files.pythonhosted.org/packages/source/z/zope.testbrowser/zope.testbrowser-%{version}.tar.gz
BuildRequires:  %{python_module setuptools}
BuildRequires:  fdupes
BuildRequires:  python-rpm-macros
# SECTION test requirements
BuildRequires:  %{python_module WSGIProxy2}
BuildRequires:  %{python_module WebTest >= 2.0.9}
BuildRequires:  %{python_module mock}
BuildRequires:  %{python_module pytz > dev}
BuildRequires:  %{python_module setuptools}
BuildRequires:  %{python_module six}
BuildRequires:  %{python_module zope.cachedescriptors}
BuildRequires:  %{python_module zope.interface}
BuildRequires:  %{python_module zope.schema}
BuildRequires:  %{python_module zope.testing}
# /SECTION
Requires:       python-WSGIProxy2
Requires:       python-WebTest >= 2.0.9
Requires:       python-pytz > dev
Requires:       python-setuptools
Requires:       python-six
Requires:       python-zope.cachedescriptors
Requires:       python-zope.interface
Requires:       python-zope.schema
Suggests:       python-zope.testing
Suggests:       python-mock
Suggests:       python-zope.testbrowser
BuildArch:      noarch

%python_subpackages

%description
The zope.testbrowser package provides an programmable web browser
with special focus on testing.  It is used in Zope, but it's not Zope
specific.  It can be used to test or otherwise interact with any web
site.

%prep
%setup -q -n zope.testbrowser-%{version}

%build
%python_build

%install
%python_install
%python_expand %fdupes %{buildroot}%{$python_sitelib}

%files %{python_files}
%doc CHANGES.rst README.rst
%license LICENSE.rst
%{python_sitelib}/*

%changelog
* Tue Dec  4 2018 mcepl@suse.com
- Remove superfluous devel dependency for noarch package
* Mon Aug  6 2018 toddrme2178@gmail.com
- Update to 5.2.4
  * Fix form submit with GET method if the form action contains a query string
    (https://github.com/zopefoundation/zope.testbrowser/pull/42).
  * Restore ignoring hidden elements when searching by label
    (https://github.com/zopefoundation/zope.testbrowser/pull/41).
- Update to 5.2.3
  * Fix ``mechRepr`` on controls to always return a native str
    (https://github.com/zopefoundation/zope.testbrowser/issues/38).
- Update to 5.2.2
  * Restore raising of AttributeError when trying to set value of a
    read only control.
  * Fix selecting radio and select control options by index
    (https://github.com/zopefoundation/zope.testbrowser/issues/31).
- Update to 5.2.1
  * Exclude version 2.0.27 of `WebTest` from allowed versions as it breaks some
    tests.
  * Adapt tests to version 2.0.28 of `WebTest` but keeping compatibility to older
    versions.
- Update to 5.2
  * Fixed ``toStr`` to handle lists, for example a list of class names.
    [maurits]
  * Fixed browser to only follow redirects for HTTP statuses
    301, 302, 303, and 307; not other 30x statuses such as 304.
  * Fix passing a real file to ``add_file``.
  * Add ``controls`` property to Form class to list all form controls.
  * Restore the ability to use parts of the actually displayed select box titles.
  * Allow to set a string value instead of a list on ``Browser.displayValue``.
  * Fix setting empty values on a select control.
  * Support Python 3.6, PyPy2.7 an PyPy3.3.
- Update to 5.1
  * Alias ``.browser.urllib_request.HTTPError`` to ``.browser.HTTPError`` to have
    a better API.
- Update to 5.0.0
  * Converted most doctests to Sphinx documentation, and published to
    https://zopetestbrowser.readthedocs.io/ .
  * Internal implementation now uses WebTest instead of ``mechanize``.
    The ``mechanize`` dependency is completely dropped.
  * *This is a backwards-incompatible change.**
  * Remove APIs:
    > ``zope.testbrowser.testing.Browser`` (this is a big one).
  * Remove modules:
    > ``zope.testbrowser.connection``
  * Remove internal classes you were not supposed to use anyway:
    > ``zope.testbrowser.testing.PublisherResponse``
    > ``zope.testbrowser.testing.PublisherConnection``
    > ``zope.testbrowser.testing.PublisherHTTPHandler``
    > ``zope.testbrowser.testing.PublisherMechanizeBrowser``
    > ``zope.testbrowser.wsgi.WSGIConnection``
    > ``zope.testbrowser.wsgi.WSGIHTTPHandler``
    > ``zope.testbrowser.wsgi.WSGIMechanizeBrowser``
  * Remove internal attributes you were not supposed to use anyway (this
    list is not necessarily complete):
    > ``Browser._mech_browser``
  * Remove setuptools extras:
    > ``zope.testbrowser[zope-functional-testing]``
  * Changed behavior:
    > The testbrowser no longer follows HTML redirects aka
    ``<meta http-equiv="refresh" ... />``. This was a `mechanize` feature which
    does not seem to be provided by `WebTest`.
  * Add support for Python 3.3, 3.4 and 3.5.
  * Drop support for Python 2.5 and 2.6.
  * Drop the ``WebTest <= 1.3.4`` pin.  We require ``WebTest >= 2.0.8`` now.
  * Remove dependency on deprecated ``zope.app.testing``.
  * Bugfix: ``browser.getLink()`` could fail if your HTML contained ``<a>``
    elements with no href attribute
  (https://github.com/zopefoundation/zope.testbrowser/pull/3).
- Implement single-spec version
* Fri May 15 2015 benoit.monin@gmx.fr
- update to version 4.0.4:
  * Removed the ‘WebTest <= 1.3.4’ version pin, fixed tests to work
    with modern WebTest versions (issue #10).
- additional changes from version 4.0.3:
    pinning version ‘WebTest <= 1.3.4’, because of some
    incompatibility and test failures
  * Make zope.testbrowser installable via pip (issue #6).
  * When Browser.handleErrors is False, also add
    x-wsgiorg.throw_errors to the environment.
    http://wsgi.org/wsgi/Specifications/throw_errors
  * Prevent WebTest from always sending paste.throw_errors=True in
    the environment by setting it to None when Browser.handleErrors
    is True. This makes it easier to test error pages.
  * Made Browser.submit() handle raiseHttpErrors (PR #4).
  * More friendly error messages from getControl() et al:
    + when you specify an index that is out of bounds, show the
    available choices
    + when you fail to find anything, show all the available items
- switch the source archive to zip (tar.gz not available)
- add unzip to BuildRequires
- add fdupes as BuildRequires and call it after install
- set a minimum version for python-mechanize
- update the test requirements (still commented, the tests fail)
- add the runtime requirements as build requirements to ensure
  their availability
- update the documentation files
* Thu Oct 24 2013 speilicke@suse.com
- Require python-setuptools instead of distribute (upstreams merged)
* Mon Mar 25 2013 speilicke@suse.com
- More on testing
* Fri Mar 15 2013 speilicke@suse.com
- Initial version
